## Immediate TODO

- [ ] Classify failed jobs
- [ ] Webhooks for starting, completed, and failed jobs (for discord)
- [ ] multi gpu jobs

## Longterm TODO

- [ ] systemctl service (better multi user)
- [ ] dependent jobs (a after b is done)
- [ ] rust rewrite for static binaries that don't require python (or venvs to be activated)
- [ ] pretty TUI front end
- [ ] multi node
- [ ] priority jobs
- [ ] vram / flop minimum
